@@ -33,10 +33,6 @@
 #  setMethod inti           'initialize', 'timeDate
 ################################################################################
 
-# ---------------------------------------------------------------------------- #
-# Roxygen Tags
-#' @export
-# ---------------------------------------------------------------------------- #
 setClass("timeDate",
          # A class implemented by Diethelm Wuertz and Yohan Chalabi
 
@@ -44,9 +40,9 @@ setClass("timeDate",
          #   Class representatation for 'timeDate' Objects.
 
          # CLASS:
-         representation(Data = "POSIXct",
-                        format = "character",
-                        FinCenter = "character"),
+         slots = c(Data = "POSIXct",
+                   format = "character",
+                   FinCenter = "character"),
          validity = function(object) {
              if(!identical(attr(object@Data, "tzone"), "GMT"))
                  return("@Data must be in \"GMT\" timezone.")
@@ -56,10 +52,7 @@ setClass("timeDate",
              TRUE
          })
 
-# ---------------------------------------------------------------------------- #
-# Roxygen Tags
-#' @export
-# ---------------------------------------------------------------------------- #
+
 setMethod("initialize", "timeDate", function(.Object, ...) {
 
     .Object <- callNextMethod()
